@@ -1,3 +1,3 @@
 require 'rbconfig'
 ruby = File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])
-exec("#{ruby} -rubygems ./exe/rake SEED=2118")
+exec("export TESTOPTS=--verbose && #{ruby} ./exe/rake")
